/*
	Figure 1.2
	Colon cancer data. Hazard and survival functions
	and their differences.
*/
version 11.0
set scheme sj
set more off
clear
use colon_uk

stset survtime, failure(dead==1) exit(time 10)
stpm2 recent, df(6) scale(hazard) eform
predict h, hazard per(1000)
predict s, s
predict hdiff, hdiff1(recent 0) hdiff2(recent 1) ci per(1000)
predict sdiff, sdiff1(recent 1) ci
 
twoway	(line h _t if recent==0, sort) ///
		(line h _t if recent==1, sort) ///
		, scheme(sj) xtitle("Years from diagnosis", size(*1)) ///
		ytitle("Mortality rate (per 1000 PYs)", size(*1)) ///
		ylabel(, angle(horizontal)) ///
		legend(order(1 "1981-1985" 2 "1986-1990") ring(0) pos(1) col(1)) ///
		title("(a)") ///
		yscale(range(0 600)) ///
		name(g1, replace) 
twoway	(rarea hdiff_lci hdiff_uci _t if _t>0.05, sort pstyle(ci)) ///
		(line hdiff _t if _t>0.05, sort lpattern(solid)) ///
		, scheme(sj) xtitle("Years from diagnosis") ///
		ytitle("Difference in mortality rate (per 1000 PYs)") ///
		ylabel(, angle(horizontal)) ///
		legend(off) ///
		title("(b)") ///
		name(g2, replace)
twoway	(line s _t if recent==0, sort) ///
		(line s _t if recent==1, sort) ///
		, scheme(sj) xtitle("Years from diagnosis", size(*1)) ///
		ytitle("Survival", size(*1)) ///
		ylabel(0(0.2)1, angle(horizontal) format(%3.1f)) ///
		legend(order(1 "1981-1985" 2 "1986-1990") ring(0) pos(1) col(1)) ///
		title("(c)") ///
		name(g3, replace)
twoway	(rarea sdiff_lci sdiff_uci _t, sort pstyle(ci)) ///
		(line sdiff _t, sort lpattern(solid)) ///
		, scheme(sj) xtitle("Years from diagnosis", size(*1)) ///
		ytitle("Difference in survival", size(*1)) ///
		ylabel(, angle(horizontal) format(%4.2f)) ///
		legend(off) ///
		title("(d)") ///
		name(g4, replace)
graph combine g1 g2 g3 g4, nocopies ysize(5)
set more on
