/*
	Figure 1.3
	Survival functions (1) from Cox and stpm assuming PH
	and (2) KM and from stpm2 not assuming PH.
*/
version 11.0
set scheme sj
set more off
clear
use kidney_ca

// Fit Cox model and predict survival
quietly stcox trt, basesurv(S0)
predict hr
gen S1 = S0^hr
replace S0 = . if trt==1
replace S1 = . if trt==0

// Same using Royston-Parmar model
quietly stpm2 trt, df(2) scale(h)
predict s0 if trt==0, surv
predict s1 if trt==1, surv

// Separate groups
sts gen S0a = s if trt==0
sts gen S1a = s if trt==1
quietly stpm2 trt, df(2) scale(h) strat(trt)
predict s0a if trt==0, surv
predict s1a if trt==1, surv

// Plot
line S0 S1 s0 s1 _t, sort lpattern(l l - -) ///
 connect (stepstair stepstair d d) lcolor(gs6 gs6 black black) ///
 ylab(, angle(h)format(%3.1f)) ///
 leg(order(1 3) label(1 "Cox (stcox)") label(3 "Royston-Parmar (stpm2)") ///
 ring(0) col(1) pos(1)) name(g1, replace) ///
 xtitle("") ytitle("") nodraw
line S0a S1a s0a s1a _t, sort clp(l l - -) ///
 connect (stepstair stepstair d d)  lcolor(gs6 gs6 black black) ///
 ylab(, angle(h) format(%3.1f)) ///
 leg(order(1 3) label(1 "Kaplan-Meier (sts gen)") label(3 "Royston-Parmar (stpm2)") ///
 ring(0) col(1) pos(1)) name(g2, replace) xtitle("") ytitle("") nodraw
graph combine g1 g2, l1title("Proportion surviving") ///
 b2title("Years from randomization")
set more on
