/*
	Figure 1.6
	E & W breast cancer data.
	Hazard functions from stpm2 cf gamma and kernel-smoothed.
*/
version 11.0
set scheme sj
set more off
clear
use EW_breast2

// Hazard using stpm2
stpm2, df(5) scale(hazard)
predict h1, hazard
lab var h1 "Hazard (stpm2)"

// Hazard from gamma distribution
streg, dist(gamma)
predict h2, hazard
lab var h2 "Hazard (gamma)"
foreach v of varlist h1 h2 {
	quietly bysort _t: replace `v' = . if _n > 1
}
// Hazard from sts graph and plot
sts graph, hazard kernel(epan2) ///
 xtitle("Years from diagnosis") ytitle("Mortality rate") title("") ///
 yscale(range(0.019 .090)) ylabel(0.020(.010).090, angle(h) format(%5.2f)) ///
 addplot(line h2 h1 _t, sort clp(- _)) ///
 legend(label(1 "Smoothed hazard function") ring(0) col(1) pos(5))
set more on
