/*
	Figure 3.3
	Orchiectomy data. Show survival and hazard functions
	in reference group, with age as time scale.
*/
version 11.0
set scheme sj
set more off
clear
use orchiectomy

keep if exposure == 0
stset enddate, failure(fracture = 1) enter(startdate) origin(birthdate) ///
 id(id) scale(365.25) exit(time birthdate + 100 * 365.24)

// Hazard - stpm2 with 4 knots
stpm2, df(5) scale(h) nolog
predict hstpm, hazard ci

// Hazard - kernel smoothing with Epanechnikov kernel (restricted to over 50)
preserve
keep if _t > 50
sts graph, hazard kernel(epan2) ci ///
 yscale(log) ylabel(0.0001 0.001 0.01 0.1, angle(h)) ///
 xtitle("Age (years)") ytitle("Hazard function (fracture rate), log scale") ///
 legend(off) name(g1, replace)
restore

// Plot hazard from stpm2
preserve
keep if _t > 50
gen tr = round(_t, .1)
qui bysort tr: drop if _n > 1
graph twoway (rarea hstpm_lci hstpm_uci tr, pstyle(ci) sort) ///
 (line hstpm tr, sort clp(l)) ///
 , yscale(log) ylabel(0.0001 0.001 0.01 0.1, angle(h)) ///
 xtitle("Age (years)") ytitle("Hazard function (fracture rate), log scale") ///
 title("Hazard function from stpm2") ///
 legend(off) name(g2, replace)
restore
graph combine g1 g2, ycommon imargin(small)

set more on
