/*
	Chapter 7
	Time-dependent poisson models using restriced cubic splines
	Includes figures 7.7, 7.8 and 7.9
*/
version 11.0
set more off
clear
use ew_breast_ch7

stset survtime, failure(dead==1) exit(time 5) id(ident)
stsplit sp_time, every(`=1/52.18')
gen risktime = _t - _t0
collapse (min) start=_t0 (max) end=_t (count) n=_d (sum) risktime _d, ///
	by(dep5 sp_time)

gen midtime = (start + end)/2
gen lntime = ln(midtime)

forvalues i = 2/6 {
	rcsgen lntime, df(`i') gen(rcs) fw(_d) orthog
	glm _d rcs* dep5, family(poisson) lnoffset(risktime) nolog eform
	estimates store df`i'
	drop rcs*
}

drop midtime lntime

gen midtime = (start + end)/2
gen lntime = ln(midtime)
rcsgen lntime, df(3) gen(rcs) fw(_d) orthog
glm _d rcs* dep5, family(poisson) lnoffset(risktime) nolog eform
estimates store pois_rcs_ph

predict log_haz_PH, xb nooffset
gen haz_PH = exp(log_haz_PH)*1000

glm _d i.dep5##c.rcs* , family(poisson) lnoffset(risktime) nolog 
estimates store rcs_tvc_df3

predict log_hazard, xb nooffset
gen hazard = 1000*exp(log_hazard)
predictnl log_hr = _b[1.dep5] + _b[1.dep5#c.rcs1]*rcs1 + ///
	_b[1.dep5#c.rcs2]*rcs2 + _b[1.dep5#c.rcs3]*rcs3, ///
	ci(log_hr_lci log_hr_uci)
gen hr = exp(log_hr)
gen hr_lci = exp(log_hr_lci)
gen hr_uci = exp(log_hr_uci)

// Figure 7.7
twoway	(line hazard midtime if dep5 == 0, lwidth(thick) lcolor(black) lpattern(solid)) ///
		(line haz_PH midtime if dep5 == 0, lwidth(thin) lcolor(black) lpattern(solid)) ///
		(line hazard midtime if dep5 == 1, lwidth(thick) lcolor(black) lpattern(dash)) ///
		(line haz_PH midtime if dep5 == 1, lwidth(thin) lcolor(black) lpattern(dash)) ///
		, yscale(log) ///
		xtitle("Time from diagnosis (years)") ///
		ytitle("Mortality rate (per 1000 PYs)") ///
		legend(order(2 "Least deprived (PH)" 1 "Least deprived (TD)" ///
					4 "Most deprived (PH)" 3 "Most deprived (TD)") ring(0) pos(1) col(1)) ///
		ylabel(50 100 150, angle(h))

// Figure 7.8
twoway	(rarea hr_lci hr_uci midtime if dep5 == 1, pstyle(ci)) ///
		(line hr midtime if dep5 == 1, lwidth(thick) lcolor(black) lpattern(solid)) ///
		, yscale(log) 		///
		xtitle("Time from Diagnosis (years)") ///
		ytitle("Hazard Ratio") ///
		yline(1, lpattern(dash)) ///
		legend(off) 

qui glm _d rcs1-rcs3 i1.dep5##c.lntime, ///
	family(poisson) lnoffset(risktime) 
estimates store lntime
rcsgen lntime, df(2) gen(rcs_df2_) fw(_d) orthog
qui glm _d rcs1-rcs3 i.dep i1.dep#c.(rcs_df2_*), ///
	family(poisson) lnoffset(risktime) 
estimates store rcs_tvc_df2
sum _d, meanonly
estimates stats lntime rcs_tvc_df2 rcs_tvc_df3, n(`r(sum)')

estimates restore lntime
predictnl log_hr_lntime = _b[1.dep5] + _b[1.dep5#c.lntime]*lntime, ///
	ci(log_hr_lntime_lci log_hr_lntime_uci)
gen hr_lntime = exp(log_hr_lntime)
gen hr_lntime_lci = exp(log_hr_lntime_lci)
gen hr_lntime_uci = exp(log_hr_lntime_uci)

// Figure 7.9
twoway	(rarea hr_lntime_lci hr_lntime_uci midtime if dep5 == 1, pstyle(ci)) ///
		(line hr_lntime midtime if dep5 == 1, lwidth(thick) lcolor(black) lpattern(solid)) ///
		(line hr_lci hr_uci midtime if dep5 == 1, lpattern(dash dash) lcolor(gs8 gs8)) ///
		(line hr midtime if dep5 == 1, lwidth(thick) lcolor(gs8) lpattern(dash)) ///
		, yscale(log) 		///
		xtitle("Time from diagnosis (years)") ///
		ytitle("Hazard ratio") ///
		yline(1, lpattern(dash)) ///
		legend(order(2 "1 d.f. (log time)" 4 "3 d.f (splines)") ring(0) pos(1) cols(1)) 
set more on
