/*
	Chapter 7
	Time dependent poisson models with various split times
	Includes figure 7.6
*/
version 11.0
set more off
clear
use ew_breast_ch7, clear

stset survtime, failure(dead==1) exit(time 5) id(ident)

local j 1
foreach split in .08333333 0.25 0.5 1 {
	preserve
	stsplit sp_time, every(`split')
	gen risktime = _t - _t0
	collapse (min) start=_t0 (max) end=_t (count) n=_d (sum) risktime _d, ///
			by(dep5 sp_time)
	tab sp_time, gen(int) nofreq
	local nint `r(r)'
	forvalues i = 1/`nint' {
		gen int`i'dep5 = int`i'*dep5
	}
	postfile hr start`j' end`j' hr`j' hr`j'_lci hr`j'_uci using poiss_hr`j', replace
	glm _d int* , family(poisson) lnoffset(risktime) nocons eform
	forvalues i = 1/`nint' {
		local hr = exp(_b[int`i'dep5])	
		local hr_lci = exp(_b[int`i'dep5] - 1.96*_se[int`i'dep5])	
		local hr_uci = exp(_b[int`i'dep5] + 1.96*_se[int`i'dep5])	
		local start = start[`i']
		local end = end[`i']
		post hr (`start') (`end') (`hr') (`hr_lci') (`hr_uci')
	}
	postclose hr
	restore
	local j = `j' + 1
}

clear
use poiss_hr1
merge using poiss_hr2
drop _merge
merge using poiss_hr3
drop _merge
merge using poiss_hr4
drop if _n == 61

gen midtime1 = (start1 + end1)/2
gen midtime2 = (start2 + end2)/2
gen midtime3 = (start3 + end3)/2
gen midtime4 = (start4 + end4)/2

local t1 "Every month"
local t2 "Every quarter of a year"
local t3 "Every half year"
local t4 "Every year"

// Figure 7.6
forvalues i = 1 / 4 { 
	twoway		(rcap hr`i'_lci hr`i'_uci midtime`i', lcolor(black)) ///
			(scatter hr`i' midtime`i', mcolor(gs6) msymbol(oh)) ///
			, legend(off) xtitle("Years from diagnosis") ///
			ylabel(0.5 1 2 4 8,angle(h) format(%3.1f)) ///
			yscale(log) ///
			ytitle("Hazard ratio") ///
			yline(1) ///
			title("`t`i''") ///
			name(g`i', replace)
}		
graph combine g1 g2 g3 g4, ycommon	
set more on			
