/*
	Chapter 8
	Poisson relative survival model using splines
	includes figures 8.3, 8.4, 8.5
*/
version 11.0
set scheme sj
set more off
clear
use breast_grouped_narrow, clear

gen midtime = (start + end)/2
gen lnmidtime = ln(midtime)
rcsgen lnmidtime, gen(rcs) df(5) fw(d) orthog

/* Proportional hazards model */
glm d rcs* i.agegroup, fam(poisson) link(rs d_star) ///
	lnoffset(y) eform nolog noheader			
estimates store ph

predict log_eh_ph, xb nooffset
gen eh_ph = exp(log_eh_ph)*1000

// Figure 8.3
twoway	(line eh_ph midtime if agegroup == 1) ///
		(line eh_ph midtime if agegroup == 2) ///
		(line eh_ph midtime if agegroup == 3) ///
		(line eh_ph midtime if agegroup == 4) ///
		(line eh_ph midtime if agegroup == 5) ///
		, yscale(log) ylabel(50 100 200 400 800, angle(h)) ///
		xtitle("Years from Diagnosis") ///
		ytitle("Excess Mortality Rate" "(per 1000 person years)") ///
		legend(order(1 "<50" 2 "50-59" 3 "60-69" 4 "70-79" 5 "80+") ///
		ring(0) pos(1) cols(1) title("Age Group"))

/* Time-dependent effect of age */		
rcsgen lnmidtime, gen(rcstvc) df(3) fw(d) orthog
tab agegroup, gen(agegrp) nofreq
forvalues i = 2/5 {
	forvalues j = 1/3 {
		gen age`i'rcs`j' = agegrp`i'*rcstvc`j'
	}
}

glm d rcs1-rcs5 agegrp2-agegrp5 age?rcs?, fam(pois) ///
	link(rs d_star) lnoffset(y) nolog noheader 			
estimates store nonph

lrtest nonph ph

predict log_eh_tvc, xb nooffset
gen eh_tvc = exp(log_eh_tvc)*1000

// Figure 8.4
twoway	(line eh_tvc midtime if agegroup == 1) ///
		(line eh_tvc midtime if agegroup == 2) ///
		(line eh_tvc midtime if agegroup == 3) ///
		(line eh_tvc midtime if agegroup == 4) ///
		(line eh_tvc midtime if agegroup == 5) ///
		, yscale(log) ylabel(50 100 200 400 800, angle(h)) ///
		xtitle("Years from Diagnosis") ///
		ytitle("Excess Mortality Rate" "(per 1000 person years)") ///
		legend(order(1 "<50" 2 "50-59" 3 "60-69" 4 "70-79" 5 "80+") ring(0) pos(1) cols(1))

/* Time-dependent excess hazard ratios */
forvalues i = 2/5 {
	predictnl lhr`i' = _b[agegrp`i'] + _b[age`i'rcs1] * age`i'rcs1 + ///
		_b[age`i'rcs2] * age`i'rcs2 + _b[age`i'rcs3] * age`i'rcs3 ///
		, ci(lhr`i'_lci lhr`i'_uci)
	gen hr`i' = exp(lhr`i')
	gen hr`i'_lci = exp(lhr`i'_lci)
	gen hr`i'_uci = exp(lhr`i'_uci)
}						  
local title2 "50-59"
local title3 "60-69"
local title4 "70-79"
local title5 "80+"

// Figure 8.5
forvalues i = 2/5 {
	twoway		(rarea hr`i'_lci hr`i'_uci midtime if agegrp`i' == 1) ///
				(line hr`i' midtime if agegrp`i' == 1, lpattern(solid)) ///
				(function y = 1, lpattern(dash) lwidth(thin) range(0 5)) ///
				, yscale(log) name(hr`i', replace) ///
				ylabel(0.5 1 2 4 8 15, format(%3.1f) angle(h)) /// 
				xtitle("Years from Diagnosis") ///
				ytitle("Excess Mortality Rate Ratio") ///
				legend(off) nodraw ///
				title("Age `title`i''")
}	
graph combine hr2 hr3 hr4 hr5, ycommon nocopies
set more on
