/*
	Chapter 8
	Relative survival with continuous effect of age
	includes figure 8.19, 8.20
*/
version 11.0
set more off
clear all
use ew_breast_ch8

stset survtime, failure(dead==1) exit(time 5) id(ident)
gen age = int(min(agediag + _t,99))
gen year = int(year(datediag) + _t)
merge m:1 sex region dep year age using popmort_uk, keepusing(rate) keep(match)

/* Fit FP model for effect of age */
fracpoly,  center(60): stpm2 agediag, df(7) scale(hazard) bhazard(rate)

estimates save mfp_stpm2, replace
estimates use mfp_stpm2

/* Excess hazard ratio as funtion of age */
gen ageround = round(agediag)
bysort ageround: gen ageflag = _n==1
predict hr_age if ageflag, hrnum(Iaged__1 . Iaged__2 .) ci

// Figure 8.19
twoway	(rarea hr_age_lci hr_age_uci agediag, sort pstyle(ci)) ///
		(line hr_age agediag, sort lpattern(solid)) ///
		, legend(off) yscale(log) ylabel(1 2 4 8 16,angle(h)) ///
		ytitle("Excess Mortality Rate Ratio") ///
		xtitle("Age at Diagnosis (years)")
		
/* Time-dependent effect of age */
gen age_fp1 = Iaged__1		
gen age_fp2 = Iaged__2		
stpm2 age_fp1 age_fp2 , df(7) scale(hazard) bhazard(rate) nolog tvc(age_fp1 age_fp2) dftvc(3)

local ref1 = (60/10)^2 - 36
local ref2 = (60/10)^3 - 216
foreach age in 30 40 50 70 80 90 {
	local c1 = (`age'/10)^2 - 36
	local c2 = (`age'/10)^3 - 216
	predict hr_age_`age', hrnum(age_fp1 `c1' age_fp2 `c2') ///
		hrdenom(age_fp1 `ref1' age_fp2 `ref2') timevar(timevar) ci
}

// Figure 8.20
foreach age in 30 40 50 70 80 90 {
twoway	(rarea hr_age_`age'_lci hr_age_`age'_uci timevar, sort pstyle(ci)) ///
		(line hr_age_`age' timevar, sort lpattern(solid)) ///
		, legend(off) yscale(log range(0.1 12)) ylabel(0.25 0.5 1 2 4 8,angle(h)) ///
		ytitle("Excess Mortality Rate Ratio") ///
		xtitle("Time from Diagnosis (years)") ///
		title("Age `age' vs Age 60") ///
		yline(1, lpattern(dash) lcolor(black)) ///
		name(g`age',replace) nodraw
}
graph combine g30 g40 g50 g70 g80 g90, nocopies ysize(3) cols(2) imargin(0 0 0 0)
set more on
