/*
	Chapter 9
	Competing risks models
	Includes figures 9.13, 9.14
	!! Needs -stcompet- to be installed from SSC (ssc install stcompet)
	!! Needs -grc1leg- to be installed from Vince Wiggins' website
*/
version 11.0
set more off
clear
use prostatecancer

/* Cumulative incidence estimates */
stset time, failure(status==1)
stcompet CI = ci , compet1(2) compet2(3) by(treatment)

// Figure 9.13
twoway	(line CI _t if status == 1 & treatment == 0, sort) ///
		(line CI _t if status == 1 & treatment == 1, sort), ///
		title("Prostate Cancer") ///
		xtitle("") ///
		ytitle("") ///
		xlabel(0(20)80) ///
		ylabel(0(0.1)0.4,angle(h) format(%3.1f)) ///
		legend(order(1 "Untreated" 2 "Treated")) ///
		scheme(sj) ///
		name(CI1,replace)
twoway	(line CI _t if status == 2 & treatment == 0, sort) ///
		(line CI _t if status == 2 & treatment == 1, sort), ///
		title("CVD") ///
		xtitle("") ///
		ytitle("") ///
		xlabel(0(20)80) ///
		ylabel(0(0.1)0.4,angle(h) format(%3.1f)) ///
		scheme(sj) ///
		name(CI2,replace)
twoway	(line CI _t if status == 3 & treatment == 0, sort) ///
		(line CI _t if status == 3 & treatment == 1, sort), ///
		title("Other Causes") ///
		xtitle("") ///
		ytitle("") ///
		xlabel(0(20)80) ///
		ylabel(0(0.1)0.4,angle(h) format(%3.1f)) ///
		scheme(sj) ///
		name(CI3,replace)
grc1leg CI1 CI2 CI3, nocopies	col(3) ///	
		b1title("Months since randomization") ///
		l1title("Cumulative Incidence") ///
		pos(12) 

gen CI_tvar = _t		


/* Expand the data in order to fit competing risks models */
expand 3
bysort id: gen byte cause = _n
generate byte cancer = cause == 1
generate byte cvd = cause == 2
generate byte other = cause == 3
generate byte tx_cancer = treatment*cancer
generate byte tx_cvd = treatment*cvd
generate byte tx_other = treatment*other
generate byte event = cause == status

stset time, failure(event) 
stcox tx_cancer tx_cvd tx_other, strata(cause) nolog noshow
stpm2 cancer cvd other tx_cancer tx_cvd tx_other, scale(hazard)  ///
	rcsbaseoff nocons tvc(cancer cvd other) dftvc(3) eform nolog

/* Model based cumulative incidence estimates */
range timevar 0.1 70 1000		
foreach cause in cancer cvd other {
	predict s_`cause'_tx0, survival at(`cause' 1) ///
		zeros timevar(timevar)
	predict s_`cause'_tx1, survival at(`cause' 1 tx_`cause' 1) ///
		timevar(timevar) zeros
	predict h_`cause'_tx0, hazard at(`cause' 1) ///
		timevar(timevar) zeros
	predict h_`cause'_tx1, hazard at(`cause' 1 tx_`cause' 1) ///
		timevar(timevar) zeros
}	

gen s_all_tx0 = s_cancer_tx0 * s_cvd_tx0 * s_other_tx0 
gen s_all_tx1 = s_cancer_tx1 * s_cvd_tx1 * s_other_tx1 

foreach cause in cancer cvd other {
	gen f_`cause'_tx0 = s_all_tx0 * h_`cause'_tx0
	gen f_`cause'_tx1 = s_all_tx1 * h_`cause'_tx1
	integ f_`cause'_tx0 timevar, gen(CIF_`cause'_tx0)
	integ f_`cause'_tx1 timevar, gen(CIF_`cause'_tx1)
}

local tcancer Cancer
local tcvd CVD
local tother Other Causes		
foreach cause in cancer cvd other {
	twoway	(line CIF_`cause'_tx0 timevar, sort lpattern(solid) lcolor(black) lwidth(thick)) ///
			(line CIF_`cause'_tx1 timevar, sort lpattern(solid) lcolor(gs10) lwidth(thick)) ///
			(line CI CI_tvar if `cause' == 1 & cause==status & treatment == 0 & CI_tvar<=70, sort ///
				lpattern(shortdash) lcolor(black) c(J)) ///
			(line CI CI_tvar if `cause' == 1 & cause==status  & treatment == 1 & CI_tvar<=70, sort ///
				lpattern(shortdash) lcolor(gs10) c(J)) ///) ///
			, name(`cause', replace) ///
			scheme(sj) ///
			title("`t`cause''") ///
			xlabel(0(20)80) ///
			ylabel(0(0.1)0.4,angle(h) format(%3.1f)) ///
			xtitle("") ///
			ytitle("") ///
			legend(order(1 "Untreated" 2 "Treated") ring(0) pos(5) cols(2))
			
}
// Figure 9.14			
grc1leg cancer cvd other, cols(3) ycommon ///
		b1title("Months since randomization") ///
		l1title("Cumulative Incidence") ///
		pos(12) 
set more on