/*
	Chapter 9
	Fits a Royston_Parmar Model in Winbugs to Rotterdam Data.
*/
version 11.0
set more off
clear
use rott2

/* Center age */
summ age
replace age = age - `r(mean)'
summ hormon
replace hormon = hormon - `r(mean)'

/* Fit RP model */
stpm2 age hormon, scale(hazard) df(3) nolog
estimates store stpm2

/* WinBUGS ANALYSIS */
gen rcs1 = _rcs1
gen rcs2 = _rcs2
gen rcs3 = _rcs3
gen drcs1 = _d_rcs1
gen drcs2 = _d_rcs2
gen drcs3 = _d_rcs3
gen t = _t
gen d = _d

/* Save variables to WinBUGS data */
scalar N = _N
wbdata, contents(wbvector d rcs1 rcs2 rcs3 drcs1 drcs2 drcs3 age hormon, ///
	format(%3.0f %12.0g %12.0g %12.0g %12.0g ///
		%12.0g %12.0g %12.0g %12.0g %3.0f) + ///
	wbscalar, scalar(N) format(%2.0f)) ///
	saving("WinBUGS/RP_rott_data.txt",replace) noprint

/* Write WinBUGS script file - change update() option to increase number of MCMC samples */
wbscript,	sav("WinBUGS/RP_rott_script.txt", replace) ///
	model("`c(pwd)'/WinBUGS/RP_rott_model.txt") ///
	data("`c(pwd)'/WinBUGS/RP_rott_data.txt") ///
	inits("`c(pwd)'/WinBUGS/RP_rott_inits.txt") ///
	burn(5000) update(5000) set(gamma beta hr.age hr.hormon) ///
	log("`c(pwd)'/WinBUGS/RP_rott_log.txt") ///
	codafile("`c(pwd)'/WinBUGS/RP_rott_coda") ///
	noprint ///
	quit

/* Run WinBUGS */	
wbrun,	script("`c(pwd)'/WinBUGS/RP_rott_script.txt") ///
	win("C:\localapp\winbugs14\winbugs14.exe")

/* Load CODA output */
wbcoda, root("WinBUGS/RP_rott_coda") clear
describe
wbstats  gamma* beta* hr*
estimates replay stpm2, eform 	
